The CosmoToolbox python module
==============================

.. module:: cosmotool


Simulation handling
^^^^^^^^^^^^^^^^^^^

The simulation data
-------------------

.. autoclass:: PySimulationBase
   :members:

.. autoclass:: SimulationBare
   :members:

.. autoclass:: Simulation
   :members:

.. autoclass:: PySimulationAdaptor
   :members:

The simulation loaders
----------------------

.. autofunction:: loadRamses
.. autofunction:: loadRamsesAll
.. autofunction:: loadGadget
.. autofunction:: loadParallelGadget

Grafic Input and Output
-----------------------

.. autofunction:: readGrafic

Timing
------

.. autofunction:: time_block
.. autofunction:: timeit
.. autofunction:: timeit_quiet 


Cosmology
^^^^^^^^^

Power spectrum
--------------

.. autoclass:: CosmologyPower
   :members:
